import { Component } from 'react';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

/**
 * @public
 */
var WeightedPicker = /** @class */ (function () {
    function WeightedPicker(count, getWeight) {
        this.count = count;
        this.getWeight = getWeight;
        this.values = [];
        if (typeof count !== 'number' || count < 0 || isNaN(count)) {
            this.count = 0;
        }
        for (var i = 0; i < this.count; i++) {
            var weight = getWeight(i);
            if (typeof weight !== 'number' || weight < 0 || isNaN(weight)) {
                weight = 0;
            }
            if (i === 0) {
                this.values.push(weight);
            }
            else {
                this.values.push(weight + this.values[this.values.length - 1]);
            }
        }
    }
    WeightedPicker.prototype.pickOne = function () {
        if (this.count === 0) {
            return -1;
        }
        if (this.count === 1) {
            var weight = this.getWeight(0);
            return typeof weight !== 'number' || weight <= 0 || isNaN(weight) ? -1 : 0;
        }
        var randomValue = Math.random() * this.values[this.values.length - 1];
        return this.binaryPick(randomValue);
    };
    WeightedPicker.prototype.binaryPick = function (value) {
        if (value < this.values[0]) {
            return 0;
        }
        var left = 0;
        var right = this.values.length - 1;
        while (left < right) {
            var middle = Math.floor((left + right) / 2);
            if (value < this.values[middle]) {
                right = middle - 1;
            }
            else if (value >= this.values[middle + 1]) {
                left = middle + 1;
            }
            else {
                return middle + 1;
            }
        }
        return right === this.values.length - 1 ? -1 : right + 1;
    };
    return WeightedPicker;
}());

var URL = "https://nw7ipb8huf.execute-api.us-east-1.amazonaws.com/Prod/runs";
var defaultWeight = 1;
var Experiment = /** @class */ (function (_super) {
    __extends(Experiment, _super);
    function Experiment(props) {
        var _this = _super.call(this, props) || this;
        var _a = _this.props, children = _a.children, forceVariant = _a.forceVariant;
        var variants = children;
        if (!variants || !Array.isArray(variants)) {
            throw Error("Experiment requires children components");
        }
        var picker = new WeightedPicker(variants.length, function (index) {
            var variant = variants[index];
            return variant.props.weight || defaultWeight;
        });
        var variantIndex = forceVariant === undefined || isNaN(parseFloat(String(forceVariant)))
            ? picker.pickOne()
            : forceVariant;
        _this.state = {
            variantIndex: variantIndex
        };
        return _this;
    }
    Experiment.prototype.componentDidMount = function () {
        this.report();
        if (this.props.onSelectedIndex) {
            this.props.onSelectedIndex(this.state.variantIndex);
        }
    };
    Experiment.prototype.shouldCollectAnalytics = function () {
        return typeof this.props.shouldCollectAnalytics === "boolean"
            ? this.props.shouldCollectAnalytics
            : process.env.NODE_ENV === "production";
    };
    Experiment.prototype.report = function (validated) {
        if (validated === void 0) { validated = false; }
        if (!this.shouldCollectAnalytics()) {
            return;
        }
        fetch(URL, {
            method: "post",
            headers: {
                Accept: "application/json, text/plain, */*",
                "Content-Type": "application/json"
            },
            body: JSON.stringify({
                testId: this.props.id,
                variantIndex: this.state.variantIndex,
                validated: validated
            })
        });
    };
    Experiment.prototype.render = function () {
        if (this.state.variantIndex === undefined || !this.props.children) {
            return undefined;
        }
        var variant = this.props.children[this.state.variantIndex];
        return variant.props.children(this.onSuccess.bind(this));
    };
    Experiment.prototype.onSuccess = function () {
        this.report(true);
    };
    return Experiment;
}(Component));
var Variant = function (_a) {
    var children = _a.children;
    return children;
};
Variant.defaultProps = {
    weight: defaultWeight
};

export { Experiment, Variant };
//# sourceMappingURL=index.es.js.map
